/*! ********************************************
 * NoiseGenerator.java
 * Copyright 2022 masahiro takamoto (MotChan)
 * Distributed under the MIT license. 
 * see -> license.txt
 ******************************************** */
	import sora.graybox.GrayBox;
	import sora.graybox.IGrayBoxModule;
	import sora.graybox.ProcessData;
// ノイズジェネレーターモジュール
public class NoiseGenerator implements IGrayBoxModule {
	public float volume = 0.1f;  // 音量
	// コンストラクター
	public NoiseGenerator() {}
// sora.graybox.IGrayBoxModule -->
	// ホストのサンプリングレートが変更された時に呼ばれるメソッド
	// GrayBox.setSampleRate() -> このメソッド
	public void updateSampleRate(float sampleRate){}
	// ホストのオーディオチャンネル数が変更された時に呼ばれるメソッド
	// GrayBox.setAudioChannels() -> このメソッド
	public void updateAudioChannels(int ch){}
	// ホストのプロセスブロックサイズが変更された時に呼ばれるメソッド
	// GrayBox.setProcessBlockSize() -> このメソッド
	public void updateProcessBlockSize(int size){}
	// ホストのGrayBox.resetModules()メソッドが使用された時に呼ばれるメソッド
	// GrayBox.resetModules() -> このメソッド
	public void resetModule(){ volume = 0.1f; }
	// ホストのGrayBox.initiModules()メソッドが使用された時に呼ばれるメソッド
	// GrayBox.initiModules() -> このメソッド
	public void initiModule(){ volume = 0.1f; }
	// このモジュールがホストへ接続された時に呼ばれるメソッド
	// GrayBox.attachModule() -> このメソッド
	public void connectModule(GrayBox host){}
	// このモジュールがホストから取り外された時に呼ばれるメソッド
	// GrayBox.detachModule() -> このメソッド
	public void disconnectModule(){}
	// このモジュールが接続されているスロットの、バイパス状況が更新された時に呼ばれるメソッド
	// GrayBox.bypassProcess() -> このメソッド
	public void updateBypassStatus(boolean bypass){}
	// ホストのGrayBox.startProcess()メソッドが使用された時に呼ばれるメソッド
	// GrayBox.startProcess() -> このメソッド
	public void startProcess(){}
	// ホストのGrayBox.stopProcess()メソッドが使用された時に呼ばれるメソッド
	// GrayBox.stopProcess() -> このメソッド
	public void stopProcess(){}
	// ホストのGrayBox.suspendProcess()メソッドが使用された時に呼ばれるメソッド
	// GrayBox.suspendProcess() -> このメソッド
	public void suspendProcess(){}
	// ホストのGrayBox.resumeProcess()メソッドが使用された時に呼ばれるメソッド
	// GrayBox.resumeProcess() -> このメソッド
	public void resumeProcess(){}
	
	// ホストが音声処理を実行した時に呼ばれるメソッド
	// GrayBox.process() -> このメソッド
	public void process(ProcessData procData) {
	// 音声処理準備 -->
		// ProcessDataオブジェクトはホストから音声処理に必要な情報を受け取り、
		// 各モジュールへ伝えるオブジェクトです。
		// ここではホストから渡されたオーディオバッファを参照して音声処理行います。
		float[] _outL = procData.audioOut[0];  // 音声出力L
		float[] _outR = procData.audioOut[1];  // 音声出力R
		int _startFrame = procData.offsetFrames;  // 音声処理開始フレーム
		int _endFrame = _startFrame + procData.sampleFrames;  // 終了フレーム
	// 音声処理 -->
		for (int i = _startFrame; i < _endFrame; i++) {
			float _n = (float)Math.random() * volume; // ノイズ音の生成
			// オーディオバッファに対して加算代入
			_outL[i] += _n; 
			_outR[i] += _n;
			// このモジュールしか音声処理を行わない場合は代入だけでも良い
			// _outL[i] = _n; 
			// _outR[i] = _n;
		}
	}
}